@@ -1,110 +1,97 @@
 #' Set or Retrieve Permanent MODIS Package Options
 #' 
 #' @description 
-#' Set or retrieve persistant \strong{MODIS} package options (per user or 
-#' systemwide). Changes here will persist through sessions and updates.
+#' Set or retrieve **MODIS** package options (per user or system-wide). If 
+#' `save = TRUE` (default), changes will persist through sessions and updates.
 #' 
-#' @param localArcPath \code{character}, defaults to 
-#' \code{file.path(tempdir(), "MODIS_ARC")}. Target folder for downloaded MODIS 
-#' HDF files. 
-#' @param outDirPath \code{character}, defaults to 
-#' \code{file.path(tempdir(), "MODIS_ARC/PROCESSED")}. Target folder for results 
-#' of \code{\link{runGdal}} and \code{\link{runMrt}}. 
+#' @param localArcPath `character`, defaults to 
+#'   `file.path(tempdir(), "MODIS_ARC")`. Target folder for downloaded MODIS HDF
+#'   files. 
+#' @param outDirPath `character`, defaults to 
+#'   `file.path(tempdir(), "MODIS_ARC/PROCESSED")`. Target folder for results 
+#'   of [runGdal()] and [runMrt()]. 
 #' @param pixelSize Output pixel size (in target reference system units) passed 
-#' to \code{\link{runGdal}} and \code{\link{runMrt}}, defaults to \code{"asIn"}.
-#' @param outProj Target reference system passed to \code{\link{runGdal}} and 
-#' \code{\link{runMrt}}. \code{\link{runGdal}} requires a valid 
-#' \code{\link{CRS}}. As for \code{\link{runMrt}}, please consult the MRT manual. 
-#' Since the two pocessing methods do not have common methods, it is suggested 
-#' to stick with the default settings (see Details).
-#' @param resamplingType Defaults to \code{"NN"} (Nearest Neighbour). MRT and 
-#' GDAL both support \code{c('NN', 'CC', 'BIL')}. GDAL additionally supports all 
-#' resampling methods listed under \url{https://gdal.org/programs/gdalwarp.html}.
-#' @param dataFormat \code{character}, defaults to \code{"GTiff"}. One of 
-#' \code{getOption("MODIS_gdalOutDriver")$name} (column 'name').
-#' @param gdalPath \code{character}. Path to gdal bin directory, used to relate 
-#' writable \code{sf::st_drivers("raster")} to file extensions in case of 
-#' non-standard formats.
-#' @param MODISserverOrder \code{character}. Possible options are \code{"LPDAAC"}
-#' (default) and \code{"LAADS"} (see 'dlmethod' and 'Details'). If only one 
-#' server is selected, all efforts to download data from the second server 
-#' are inhibited.
-#' @param dlmethod \code{character}, defaults to \code{auto}. See 'method' in 
-#' \code{\link{download.file}}. On Unix (also Mac?), it is suggested to use 
-#' \code{"wget"} or, if installed, \code{"aria2"} (supports multi source download).
-#' Be aware that in order to download files from any server, either wget (default) 
-#' or curl must be installed and made available through the system's PATH 
-#' environmental variable.
-#' @param stubbornness \code{numeric}. The number of retries after the target 
-#' server has refused a connection. Higher values increase the chance of getting 
-#' the file, but also lead to hanging functions if the server is down.
-#' @param wait \code{numeric} waiting time (in seconds) inserted after each 
-#' internal online download call via \code{\link{download.file}} or 
-#' \code{\link[curl]{curl}}. Reduces the chance of connection errors that 
-#' frequently occur after many requests.
-#' @param cellchunk Default 1 (=use raster default), comparable with chunksize
-#' in \code{\link{rasterOptions}}. But as no effect was found in adapting chunksize, 
-#' MODIS applies its own variant:
-#' \strong{minrows <- max(floor(cellchunk/ncol(x)),1) 
-#' blockSize(x,minrows=minrows)}. 
-#' On a reasonable working station you can easily increase cellchunk to 500000.
-#' @param systemwide A \code{logical} determining whether changes made to 
-#' \code{\link{MODISoptions}} are to be applied system or user-wide (default), 
-#' see 'Details'.
-#' @param quiet \code{logical} passed eg to \code{\link{download.file}} which is 
-#' called from inside \code{\link{getHdf}}. 
-#' @param save \code{logical}. If \code{TRUE} (default), settings are permanent.
-#' @param checkTools \code{logical}, defaults to \code{TRUE}. Check if external 
-#' tools (i.e., GDAL and MRT) are installed and reachable through R.
-#' @param checkWriteDrivers \code{logical}. If \code{TRUE} (default), find write 
-#' drivers supported by \strong{sf} GDAL installation.
-#' @param ask \code{logical}. If \code{TRUE} (default) and permanent settings 
-#' file does not exist (see Details), the user is asked whether to create it.
+#'   to [runGdal()] and [runMrt()], defaults to `"asIn"`.
+#' @param outProj Target reference system passed to [runGdal()] and 
+#'   [runMrt()]. [runGdal()] requires a valid CRS. As for [runMrt()], please 
+#'   consult the MRT manual. Since the two processing methods do not have common
+#'   methods, it is suggested to stick with the default settings (see Details).
+#' @param resamplingType Defaults to `"NN"` (Nearest Neighbor). MRT and GDAL 
+#'   both support `c('NN', 'CC', 'BIL')`. GDAL additionally supports all 
+#'   resampling methods listed under <https://gdal.org/programs/gdalwarp.html>.
+#' @param dataFormat `character`, defaults to `"GTiff"`. See
+#'   `sf::st_drivers(what = "raster")` for available options.
+#' @param gdalPath `character`. Path to GDAL binary executable, used to relate 
+#'   writable `sf::st_drivers("raster")` to file extensions in case of 
+#'   non-standard formats.
+#' @param MODISserverOrder `character`. Possible options are `"LPDAAC"` 
+#'   (default), `"LAADS"` (see 'dlmethod' and Details). If only one server is 
+#'   selected, all efforts to download data from the second server are 
+#'   inhibited.
+#' @param dlmethod `character`, defaults to `"auto"`. See 'method' in 
+#'   [utils::download.file()] for available options. If installed, you can also 
+#'   leverage `"aria2"` for multi-source download. Note that in any case, either
+#'   curl or wget must be installed and made available through the system's PATH
+#'   environment variable to validate Earthdata Login credentials.
+#' @param stubbornness `numeric`. The number of retries after the target server 
+#'   has refused a connection. Higher values increase the chance of getting the 
+#'   file, but also lead to hanging functions if the server is down.
+#' @param wait `numeric` waiting time (in seconds) inserted after each internal 
+#'   online download call via [utils::download.file()] or [curl::curl()]. 
+#'   Reduces the chance of connection errors that may occur after many requests.
+#' @param cellchunk Default `1`, i.e. use raster default. Comparable with 
+#'   'chunksize' in [raster::rasterOptions()], but as no effect was found in 
+#'   adapting chunksize, **MODIS** applies its own variant. On a reasonable 
+#'   working station, 'cellchunk' can easily be increased to `5e5`.
+#' @param systemwide A `logical` determining whether changes made to 
+#'   [MODISoptions()] are to be applied system-wide or per user (default), see 
+#'   Details.
+#' @param quiet `logical` passed e.g. to [utils::download.file()] and
+#'   [sf::gdal_utils()]. 
+#' @param save `logical`. If `TRUE` (default), settings are permanent.
+#' @param checkTools `logical`, defaults to `TRUE`. Check if external tools 
+#'   (i.e., GDAL and MRT) are installed and reachable through R.
+#' @param checkWriteDrivers `logical`. If `TRUE` (default), find write drivers 
+#'   supported by **sf** GDAL installation.
+#' @param ask `logical`. If `TRUE` (default) and permanent settings file does 
+#'   not exist (see Details), the user is asked whether to create it.
+#' @param check_earthdata_login `logical`. If `TRUE` (default), look for 
+#'   Earthdata Login credentials in `~/.netrc` and try to download a small 
+#'   sample `.hdf` file.
 #' 
 #' @return 
-#' An invisible \code{list} of \strong{MODIS} options. In addition, the most 
-#' relevant of these options are printed to the console. Use 
-#' \code{\link{capture.output}} to prevent this behavior.
+#' An invisible `list` of **MODIS** options. In addition, the most relevant of 
+#' these options are printed to the console. Use [utils::capture.output()] to 
+#' prevent this behavior.
 #' 
 #' @details 
 #' These settings are easy to change and take effect immediately! However, 
-#' please mind that the \href{https://cran.r-project.org/web/packages/policies.html}{CRAN Repository Policy}
+#' please mind that the 
+#' [CRAN Repository Policy](https://cran.r-project.org/web/packages/policies.html)
 #' does not permit automated write access to the user's file system exempt for 
-#' \code{\link{tempdir}}. Therefore, changes made to \code{\link{MODISoptions}} 
-#' remain temporally limited to the current \strong{\code{R}} session unless write 
-#' access is explicitly granted by the user in interactive mode, in which case a 
-#' permanent settings file is created in \code{file.path("~/.MODIS_Opts.R")} 
-#' (user-wide) or \code{file.path(R.home(component = "etc"), '.MODIS_Opts.R')}
-#' (system-wide, write access provided).
+#' [tempdir()]. Therefore, changes made to [MODISoptions()] remain temporary for
+#' the current session unless write access is explicitly granted by the user in 
+#' interactive mode, in which case a permanent settings file is created in 
+#' `file.path("~/.MODIS_Opts.R")` (per user) or 
+#' `file.path(R.home(component = "etc"), '.MODIS_Opts.R')` (system-wide, write 
+#' access provided).
 #' 
 #' Due to similar reasons, 'localArcPath' and 'outDirPath' default to 
-#' \strong{\code{R}}'s \code{\link{tempdir}} and should be changed immediately 
-#' after loading the package in order to make downloaded files permanently 
-#' available. You may also specify a shared network drive if you have a central 
-#' MODIS data server. 
+#' [tempdir()] and should be changed immediately after loading the package in 
+#' order to make downloaded files permanently available. You may also specify a 
+#' shared network drive if you have a central MODIS data server. 
 #' 
 #' If you change default values, consider that your settings have to be valid 
 #' for any MODIS product, layer and area!
 #' 
-#' It is not recommended to use 
-#' \itemize{
-#' \item{a coordinate reference system that is not applicable globally as 
-#' default for 'outProj',}
-#' \item{or a fixed 'pixelSize' for different products,}
-#' \item{or a 'resamplingType' that is not \code{"NN"}.}
-#' }
-#' 
-#' On an unixoid OS, it is suggested to use \code{dlmethod = 'wget'} because it 
-#' is a reliable tool and, after the change of the 'LP DAAC' datapool from FTP 
-#' to HTTP (May 2013), \code{dlmethod = 'auto'} seems not to work properly. On 
-#' Windows, on the other hand, \code{dlmethod = 'auto'} seems to work fine. 
-#' 
 #' Please note that in order to download MODIS files from any available server, 
-#' you are required to register for an Earthdata Login Profile 
-#' (\url{https://urs.earthdata.nasa.gov/users/new}) and create a read-only 
-#' .netrc file in your home directory containing the Earthdata server address as 
-#' well as your login credentials. An automated solution for the creation of a 
-#' workable .netrc file is provided through \code{\link[MODIS]{EarthdataLogin}}. 
+#' you are required to 
+#' * register for an Earthdata Login profile at
+#'   <https://urs.earthdata.nasa.gov/users/new>, 
+#' * fill out mandatory fields therein, and
+#' * create a `.netrc` file in your home directory containing the Earthdata 
+#'   server address and your login credentials. An automated solution for the 
+#'   creation of such a file is provided through [EarthdataLogin()]. 
 #' 
 #' @author 
 #' Matteo Mattiuzzi, Steven Mosher and Florian Detsch
@@ -127,7 +114,8 @@ MODISoptions <- function(localArcPath, outDirPath, pixelSize, outProj,
                          resamplingType, dataFormat, gdalPath, MODISserverOrder, 
                          dlmethod, stubbornness, wait, quiet, cellchunk,
                          systemwide = FALSE, save = TRUE, checkTools = TRUE,
-                         checkWriteDrivers = TRUE, ask = TRUE)
+                         checkWriteDrivers = TRUE, ask = TRUE, 
+                         check_earthdata_login = TRUE)
 {
   # This function collects the package options from up to 3 files and creates 
   # the .MODIS_Opts.R file (location depending on systemwide=T/F, see below):
@@ -264,7 +252,17 @@ MODISoptions <- function(localArcPath, outDirPath, pixelSize, outProj,
   if(!missing(dlmethod))
   {
     dlmethod <- tolower(dlmethod)
-    stopifnot(dlmethod %in% c("auto","internal","wget","curl","lynx","aria2"))
+    stopifnot(
+      dlmethod %in% c(
+        "internal"
+        , if (Sys.info()[["sysname"]] == "Windows") "wininet"
+        , "libcurl"
+        , "wget"
+        , "curl"
+        , "auto"
+        , "aria2"
+      )
+    )
     opt$dlmethod <- dlmethod
   }
   
@@ -300,28 +298,39 @@ MODISoptions <- function(localArcPath, outDirPath, pixelSize, outProj,
 
   if(is.null(opt$MODISserverOrder))
   {
-    opt$MODISserverOrder <- c("LPDAAC", "LAADS")
+    opt$MODISserverOrder <- c("LPDAAC", "LAADS", "NSIDC")
   }
-  if (!missing(MODISserverOrder))
-  {
-    MODISserverOrder <- toupper(MODISserverOrder)
-    if(length(MODISserverOrder)==1)
-    {
-      if("LPDAAC" %in% MODISserverOrder | "LAADS" %in% MODISserverOrder)
-      {
-        opt$MODISserverOrder <- MODISserverOrder   
-      }
-    } else if(length(MODISserverOrder)==2)
-    {
-      if("LPDAAC" %in% MODISserverOrder & "LAADS" %in% MODISserverOrder)
-      {
-        opt$MODISserverOrder <- MODISserverOrder   
-      }
-    } else
-    {
-      stop("Provide valid 'MODISserverOrder' see '?MODISoptions'") 
+  if (!missing(MODISserverOrder)) {
+    
+    MODISserverOrder = intersect(
+      toupper(
+        MODISserverOrder
+      )
+      , c("LPDAAC", "LAADS", "NSIDC")
+    )
+    
+    if (length(MODISserverOrder) == 0L) {
+      stop(
+        "Provide valid 'MODISserverOrder', see `?MODISoptions()`."
+        , call. = FALSE
+      ) 
     }
-  }  
+    
+    opt$MODISserverOrder = MODISserverOrder
+  }
+  
+  if (
+    (
+      is.null(opt$EarthdataLogin) || # check never performed
+      isFALSE(opt$EarthdataLogin)    # check performed, but failed
+    ) && 
+    check_earthdata_login
+  ) {
+    opt$EarthdataLogin = checkEarthdataLogin(
+      opt$dlmethod
+      , opt$MODISserverOrder
+    )
+  }
   
   # checks if the pointed GDAL exists and supports 'HDF4Image' driver.
   if(checkTools)
@@ -422,7 +431,8 @@ MODISoptions <- function(localArcPath, outDirPath, pixelSize, outProj,
     write('# consult \'?MODISoptions\' for more details', filename)
     write('  ', filename)
     
-    if(length(opt$MODISserverOrder)==2)
+    write(paste0('EarthdataLogin   <- ', ifelse(is.null(opt$EarthdataLogin), FALSE, opt$EarthdataLogin)), filename)
+    if(length(opt$MODISserverOrder)>=2)
     {
       write(paste0('MODISserverOrder <- c(\'',paste(opt$MODISserverOrder,collapse="', '"),'\')' ), filename)
     } else
@@ -482,6 +492,7 @@ MODISoptions <- function(localArcPath, outDirPath, pixelSize, outProj,
   
   cat('DOWNLOAD:\n')
   cat('_______________\n')
+  cat('EarthdataLogin   :', opt$EarthdataLogin, "\n")
   cat('MODISserverOrder :', paste(opt$MODISserverOrder,collapse=", "),'\n')
   cat('dlmethod         :', opt$dlmethod,'\n')
   cat('stubbornness     :', opt$stubbornness,'\n')
